@@ -486,7 +486,8 @@ print "WHAT IS THISSSSS=$self->{ppk_file}\n";
          $count++;
          if ($line=~/GNU.io/) {
             next;
-         } elsif ($line=~/ACCESS (?:HADOOP|KALI|OPENLDAP|CATALYST|GNU)/) {
+         } elsif (
+               $line=~/ACCESS (?:HADOOP|KALI|OPENLDAP|CATALYST|GNU|CLIP)/) {
             last;
          } elsif ($line=~/ACCESS.*AT:\s+http:/ && $count<70) {
             $webapp_url=$line;
